/************************************************************************/
/*                                                                      */
/*                      RC5 Remote Receiver                             */
/*                                                                      */
/*              Author: Peter Dannegger                                 */
/*                      danni@specs.de                                  */
/*                                                                      */
/************************************************************************/

#include <avr/io.h>                   // I/O Ports
#include <avr/interrupt.h>            // Interrupts
#include <stdint.h>                   // Standard data types

#include "rc5.h"

struct RC5STRUCT rc5;


void rc5_scheduler(void)
{
  unsigned int tmp = rc5.tmp;             // for faster access

  TCNT0 = -2;                             // 2 timer cycles until next interrupt

  if( ++rc5.time > PULSE_MAX )            // count pulse time
  {
    if( !(tmp & 0x4000) && tmp & 0x2000 ) // only if 14 bits received
      rc5.data = tmp;
    tmp = 0;
  }

  if( (rc5.bit ^ xRC5_IN) & 1<<xRC5 )     // change detect
  {
    rc5.bit = ~rc5.bit;                   // 0x00 -> 0xFF -> 0x00

    if( rc5.time < PULSE_MIN )            // to short
    {
      tmp = 0;
    }

    if( !tmp || rc5.time > PULSE_1_2 )    // start or long pulse time
    {
      if( !(tmp & 0x4000) )               // not to many bits
        tmp <<= 1;                        // shift

      if( !(rc5.bit & 1<<xRC5) )          // inverted bit
        tmp |= 1;                         // insert new bit

      rc5.time = 0;                       // count next pulse time
    }
  }

  rc5.tmp = tmp;
}
